Learn R Programming

RClone (version 1.0)

Pareto_index: Pareto index

Description

Pareto_index computes parameters of the Pareto distribution.

Usage

Pareto_index(data1, vecpop = NULL, listMLL = NULL, full = FALSE, graph = FALSE, 
				legends = 1, export = FALSE)

Arguments

data1
a Rclone table with one allele per column, haploid or diploid data.
vecpop
vector, option, vecpop indicates the population name of each unit of data1, if data1 contains several populations. If data1 contains only one population, leave vecpop =
listMLL
option, a custom list of MLL.
full
option, if TRUE, gives more detailed results.
graph
option, if TRUE, displays plot of the inverse cumulated frequency of the number of lineages.
export
option, if TRUE, graph is saved as .eps into working directory.
legends
option, numerical, with graph = TRUE, legends = 1 gives the log-log regression equation; legends = 2 gives the Pareto index, the r2 and the p-value of the regression.

Value

  • A list of:
  • ParetoPareto's Beta,
  • c_Paretodistribution of clonal size in the population,
  • coefficients and regression_resultssummary of the linear regression,
  • coords_Paretox and y coordinates of the inverse cumulated frequencies.
  • For several populations, a list of lists per population.

Details

Pareto's Beta is given as -slope of the linear regression of the inverse cumulated frequency of the number of lineages (Pareto 1897 in Vidondo 1997). The distribution of clonal size in the population c_Pareto is computed as slope+1 (Schroeder 1991).

References

Arnaud-Haond et al., 2007, Standardizing methods to address clonality in population studies.

See Also

clonal_index

Examples

Run this code
data(posidonia)

Pareto_index(posidonia, graph = TRUE, legends = 2)

res <- Pareto_index(posidonia, full = TRUE)[[4]]

xi <- res[,1]
yi <- res[,2]
exp(summary(lm(log10(yi)~log10(xi)))$coefficients[1]) ##true b of y=ax+b

Run the code above in your browser using DataLab