Arguments
data1
a Rclone table with one allele per column, haploid or diploid data.
vecpop
vector, option, vecpop indicates the population name of each unit
of data1, if data1 contains several populations.
If data1 contains only one population, leave vecpop =
listMLL
option, a custom list of MLL.
full
option, if TRUE, gives more detailed results.
graph
option, if TRUE, displays plot of the inverse cumulated frequency of
the number of lineages.
export
option, if TRUE, graph is saved as .eps into working directory.
legends
option, numerical, with graph = TRUE, legends = 1 gives
the log-log regression equation;
legends = 2 gives the Pareto
index, the r2 and the p-value of the regression.